@@ -1,14 +1,14 @@
 import unittest
 
-from ansiblelint import RulesCollection
+from ansiblelint.rules import RulesCollection
 from ansiblelint.rules.LineTooLongRule import LineTooLongRule
-from test import RunFromText
+from ansiblelint.testing import RunFromText
 
 LONG_LINE = '''
 - name: task example
   debug:
     msg: 'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua tempor incididunt ut labore et dolore'
-'''
+'''  # noqa 501
 
 
 class TestLineTooLongRule(unittest.TestCase):
