@@ -1,9 +1,8 @@
 import unittest
 
-from ansiblelint import RulesCollection
-from ansiblelint.rules.MetaChangeFromDefaultRule import (
-    MetaChangeFromDefaultRule)
-from test import RunFromText
+from ansiblelint.rules import RulesCollection
+from ansiblelint.rules.MetaChangeFromDefaultRule import MetaChangeFromDefaultRule
+from ansiblelint.testing import RunFromText
 
 DEFAULT_GALAXY_INFO = '''
 galaxy_info:
