@@ -1,8 +1,8 @@
 import unittest
 
-from ansiblelint import RulesCollection
+from ansiblelint.rules import RulesCollection
 from ansiblelint.rules.MetaTagValidRule import MetaTagValidRule
-from test import RunFromText
+from ansiblelint.testing import RunFromText
 
 META_TAG_VALID = '''
 galaxy_info:
