@@ -1,8 +1,8 @@
 import unittest
 
-from ansiblelint import RulesCollection
+from ansiblelint.rules import RulesCollection
 from ansiblelint.rules.VariableHasSpacesRule import VariableHasSpacesRule
-from test import RunFromText
+from ansiblelint.testing import RunFromText
 
 TASK_VARIABLES = '''
 - name: good variable format
@@ -11,11 +11,17 @@ TASK_VARIABLES = '''
 - name: good variable format
   debug:
     msg: "Value: {{ good_format }}"
-- name: jijna escaping allowed
+- name: jinja escaping allowed
   debug:
     msg: "{{ '{{' }}"
-- name: jijna escaping allowed
+- name: jinja escaping allowed
   shell: docker info --format '{{ '{{' }}json .Swarm.LocalNodeState{{ '}}' }}' | tr -d '"'
+- name: jinja whitespace control allowed
+  debug:
+    msg: |
+      {{ good_format }}/
+      {{- good_format }}
+      {{- good_format -}}
 - name: bad variable format
   debug:
     msg: "{{bad_format}}"
@@ -25,6 +31,13 @@ TASK_VARIABLES = '''
 - name: bad variable format
   debug:
     msg: "{{bad_format }}"
+- name: not a jinja variable
+  debug:
+    msg: "test"
+  example: "data = ${lookup{$local_part}lsearch{/etc/aliases}}"
+- name: JSON inside jinja is valid
+  debug:
+    msg: "{{ {'test': {'subtest': variable}} }}"
 '''
 
 
